OC.L10N.register(
    "core",
    {
    "Please select a file." : "Iltimos, faylni tanlang.",
    "File is too big" : "Fayl juda katta",
    "The selected file is not an image." : "Tanlangan fayl rasm emas.",
    "The selected file cannot be read." : "Tanlangan faylni o'qib bo'lmaydi.",
    "The file was uploaded" : "Fayl yuklangan edi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yuklangan fayl php.ini dagi php-dagi upload_max_filesize direktivasidan oshadi",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yuklangan fayl HTML shaklida ko'rsatilgan MAX_FILE_SIZE direktivasidan oshadi",
    "The file was only partially uploaded" : "Fayl faqat qisman yuklandi",
    "No file was uploaded" : "Fayl yuklanmadi",
    "Missing a temporary folder" : "Vaqtinchalik papka etishmayapti",
    "Could not write file to disk" : "Faylni diskka yozib bo'lmadi",
    "A PHP extension stopped the file upload" : "PHP kengaytmasi faylni yuklashni to'xtatdi",
    "Invalid file provided" : "Noto'g'ri fayl taqdim etildi",
    "No image or file provided" : "Rasm yoki fayl taqdim etilmaydi",
    "Unknown filetype" : "Noma'lum fayl turi",
    "An error occurred. Please contact your admin." : "Xatolik yuz berdi. O`z adminingizga murojaat qiling.",
    "Invalid image" : "Noto'g'ri rasm",
    "State token does not match" : "Token mos emas",
    "Invalid app password" : "Ilova paroli noto'g'ri",
    "Could not complete login" : "Kirishni yakunlab bo'lmadi",
    "State token missing" : "Token yo'qotilgan",
    "Your login token is invalid or has expired" : "Kirish tokeningiz yaroqsiz yoki muddati tugagan",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Next cloud-ning ushbu jamoatchilik versiyasi qo'llab-quvvatlanmaydi va push xabarnomalari cheklangan.",
    "Login" : "Login",
    "Unsupported email length (>255)" : "Qo'llab-quvvatlanmaydigan elektron pochta uzunligi (>255)",
    "Password reset is disabled" : "Parolni tiklash o'chirilgan",
    "Could not reset password because the token is expired" : "Parolni tiklab bo'lmadi, chunki token muddati tugagan",
    "Could not reset password because the token is invalid" : "Parolni tiklab bo'lmadi, chunki token yaroqsiz",
    "Password is too long. Maximum allowed length is 469 characters." : "Parol juda uzun. Maksimal ruxsat etilgan uzunlik 469 belgidan iborat.",
    "%s password reset" : "parolni tiklash %s ",
    "Password reset" : "Parolni tiklash",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Parolni tiklash uchun quyidagi tugmani bosing. Agar siz parolni tiklashni talab qilmagan bo'lsangiz, ushbu elektron pochtaga e'tibor bermang.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Parolni tiklash uchun quyidagi havolani bosing. Agar siz parolni tiklashni talab qilmagan bo'lsangiz, ushbu elektron pochtaga e'tibor bermang.",
    "Reset your password" : "Parolni tiklash",
    "The given provider is not available" : "Berilgan provayder mavjud emas",
    "Task not found" : "Vazifa topilmadi",
    "Internal error" : "Ichki xato",
    "Not found" : "Topilmadi",
    "Bad request" : "Yomon talab",
    "Requested task type does not exist" : "Talab qilingan vazifa turi mavjud emas",
    "Necessary language model provider is not available" : "Kerakli til modeli provayderi mavjud emas",
    "No text to image provider is available" : "Rasm provayderiga matn mavjud emas",
    "Image not found" : "Rasm topilmadi",
    "No translation provider available" : "Tarjima provayderi mavjud emas",
    "Could not detect language" : "Tilni aniqlab bo'lmadi",
    "Unable to translate" : "Tarjima qilib bo'lmadi",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Ta'mirlash bosqichi:",
    "Repair info:" : "Repair info:",
    "Repair warning:" : "Ta'mirlash haqida ogohlantirish:",
    "Repair error:" : "Ta'mirlash xatosi:",
    "Nextcloud Server" : "Next bulutli Server",
    "Some of your link shares have been removed" : "Sizning havola aktsiyalaringizdan ba'zilari olib tashlandi",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Xavfsizlik xatosi tufayli biz sizning ba'zi havolalaringizni olib tashlashimiz kerak edi. Qo'shimcha ma'lumot olish uchun link qarang.",
    "The account limit of this instance is reached." : "Ushbu akkauntning namuna chegarasiga limitiga erishildi.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Hisob cheklovini oshirish uchun obuna kalitini qo'llab-quvvatlash ilovasiga kiriting. Bu sizga Next cloud Enterprise taklif qiladigan va kompaniyalarda ishlash uchun juda tavsiya etiladigan barcha qo'shimcha imtiyozlarni beradi.",
    "Learn more ↗" : "Ko'proq ma'lumot oling. ↗",
    "Preparing update" : "Yangilanish tayyorlanmoqda",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Iltimos, buyruq satrini yangilashdan foydalaning, chunki config.php da brauzer orqali yangilash o'chirilgan.",
    "Turned on maintenance mode" : "Ta'minot rejimi yoqilgan",
    "Turned off maintenance mode" : "Ta'minot rejimi o'chirilgan",
    "Maintenance mode is kept active" : "Ta'minot rejimi faol saqlanadi",
    "Updating database schema" : "Ma'lumotlar bazasi sxemasini yangilash",
    "Updated database" : "Yangilangan ma'lumotlar bazasi",
    "Update app \"%s\" from App Store" : "App Store dan \"%s\" Ilovani yangilang",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : " %s uchun maʼlumotlar bazasi sxemasini yangilash mumkinmi yoki yoʻqligini tekshirish (bu maʼlumotlar bazasi hajmiga qarab uzoq vaqt talab qilishi mumkin)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\" dan %2$syangilandi",
    "Set log level to debug" : "Xatolikni tuzatish uchun jurnal darajasini o'rnating",
    "Reset log level" : "Jurnal darajasini tiklash",
    "Starting code integrity check" : "Kodning yaxlitligini tekshirishni boshlash",
    "Finished code integrity check" : "Kodning yaxlitligini tekshirish tugadi",
    "%s (incompatible)" : "%s (mos kelmaydigan)",
    "The following apps have been disabled: %s" : "Quyidagi ilovalar o'chirilgan:  %s",
    "Already up to date" : "Allaqachon dolzarb",
    "Unknown" : "Noma'lum",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Yangilanish davom etmoqda, bu sahifani tark etish ba'zi muhitlarda jarayonni to'xtatishi mumkin.",
    "Update to {version}" : " {version}ni yangilash",
    "An error occurred." : "Xatolik yuz berdi.",
    "Please reload the page." : "Iltimos, sahifani qayta yuklang.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Yangilash muvaffaqiyatsiz tugadi. Qo'shimcha ma'lumot olish uchun <a href=\"{url}\">ushbu muammoga bag'ishlangan forum postimizni</a> tekshiring.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Yangilash muvaffaqiyatsiz tugadi. Iltimos, bu muammo haqida  <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud hamjamiyatiga </a> xabar qiling..",
    "Continue to {productName}" : " {productName}ni davom eting",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : [" {productName}ni yangilanish muvaffaqiyatli bo'ldi. Sizni yo'naltirish %n sekund."],
    "Applications menu" : "Ilovalar menyusi",
    "Apps" : "Ilovalar",
    "More apps" : "Ko'proq ilovalar",
    "_{count} notification_::_{count} notifications_" : ["{count} bildirishnomalarnotifications"],
    "No" : "Yo`q",
    "Yes" : "Ha",
    "The remote URL must include the user." : "Masofaviy URL foydalanuvchini o'z ichiga olishi kerak.",
    "Invalid remote URL." : "Xato masofadagi URL.",
    "Failed to add the public link to your Nextcloud" : "Keyingi bulutga umumiy havolani qo'shib bo'lmadi",
    "Federated user" : "Korporativ foydalanuvchi",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Tarqatish yaratish",
    "Please copy the link manually:" : "Iltimos, havolani qo'lda nusxalash:",
    "Custom date range" : "Maxsus sana oralig'i",
    "Pick start date" : "Boshlanish sanasini tanlang",
    "Pick end date" : "Tugash sanasini tanlang",
    "Search in date range" : "Sana oralig'ida qidirish",
    "Search in current app" : "Joriy ilovada qidirish",
    "Clear search" : "Qidiruvni tozalash",
    "Search everywhere" : "Hamma joyda qidirish",
    "Start typing to search" : "Qidirish uchun yozishni boshlang",
    "No matching results" : "Natijalar taaluqli emas",
    "Today" : "Bugun",
    "Last 7 days" : "Oxirgi 7 kun",
    "Last 30 days" : "Oxirgi 30 kun",
    "This year" : "Shu yil",
    "Last year" : "O`tgan yil",
    "Unified search" : "Yagona qidiruv",
    "Search apps, files, tags, messages" : "Ilovalar, fayllar, teglar, xabarlarni qidirish",
    "Places" : "Joylar",
    "Date" : "Sana",
    "Search people" : "Shaxsni qidirish",
    "People" : "Shaxs",
    "Filter in current view" : "Joriy ko'rinishda filtrlash",
    "Results" : "Natijalar",
    "Load more results" : "Ko'proq natijalarni yuklang",
    "Search in" : "Qidirish",
    "Log in" : "Kirish",
    "Log in to {productName}" : " {productName}ga kirish",
    "Wrong login or password." : "Noto'g'ri login yoki parol.",
    "This account is disabled" : "Bu akkaunt o'chirilgan",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Biz sizning IP-dan bir nechta noto'g'ri kirish urinishlarini aniqladik. Shuning uchun sizning keyingi kirishingiz 30 soniyagacha qisqartiriladi.",
    "Account name or email" : "Akkaunt nomi yoki elektron pochta",
    "Account name" : "Akkaunt nomi",
    "Server side authentication failed!" : "Server tomoni autentifikatsiyasi muvaffaqiyatsiz tugadi!",
    "Please contact your administrator." : "Iltimos, administratoringizga murojaat qiling.",
    "Session error" : "Seans xatosi",
    "It appears your session token has expired, please refresh the page and try again." : "Tokeningiz seans muddati tugaganga o‘xshaydi, sahifani yangilang va qayta urinib ko‘ring.",
    "An internal error occurred." : "Ichki xato yuz berdi.",
    "Please try again or contact your administrator." : "Iltimos, qayta urinib ko'ring yoki administratoringizga murojaat qiling.",
    "Password" : "Parol",
    "Log in with a device" : "Qurilma orqali tizimga kiring",
    "Login or email" : "Login yoki elektron pochta",
    "Your account is not setup for passwordless login." : "Sizning akkauntingiz parolsiz kirish uchun sozlanmagan.",
    "Your connection is not secure" : "Sizning ulanishingiz xavfsiz emas",
    "Passwordless authentication is only available over a secure connection." : "Parolsiz autentifikatsiya faqat xavfsiz ulanish orqali mavjud.",
    "Browser not supported" : "Brauzer qo'llab-quvvatlanmaydi",
    "Passwordless authentication is not supported in your browser." : "Parolsiz autentifikatsiya brauzeringizda mavjud emas.",
    "Reset password" : "Parolni tiklash",
    "Back to login" : "Kirishga qaytish",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Agar ushbu hisob mavjud bo'lsa, uning elektron pochta manziliga parolni tiklash to'g'risida xabar yuborilgan. Agar siz uni qabul qilmasangiz, elektron pochta manzilingizni va/yoki loginingizni tasdiqlang, spam/keraksiz papkalarni tekshiring yoki mahalliy ma'muriyatdan yordam so'rang.",
    "Couldn't send reset email. Please contact your administrator." : "Elektron pochtasini qayta tiklash xabarini yuborib bo'lmadi. Iltimos, administratoringizga murojaat qiling.",
    "Password cannot be changed. Please contact your administrator." : "Parolni o'zgartirib bo'lmaydi. Iltimos, administratoringizga murojaat qiling.",
    "New password" : "Yangi parol",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Fayllaringiz shifrlangan. Parolingiz tiklangandan so'ng ma'lumotlaringizni qaytarib olishning hech qanday usuli bo'lmaydi. Agar nima qilishni bilmasangiz, davom etishdan oldin administratoringizga murojaat qiling. Siz haqiqatan ham davom etishni xohlaysizmi?",
    "I know what I'm doing" : "Men nima qilayotganimni bilaman",
    "Resetting password" : "Parolni tiklash",
    "Schedule work & meetings, synced with all your devices." : "Barcha qurilmalaringiz bilan sinxronlangan ish va uchrashuvlarni rejalashtiring.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Hamkasblaringiz va do'stlaringizni shaxsiy ma'lumotlarini oshkor qilmasdan bir joyda saqlang.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Oddiy elektron pochta ilovasi fayllar, kontaktlar va taqvim bilan yaxshi birlashtirilgan.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Suhbat, video qo'ng'iroqlar, ekran almashish, onlayn uchrashuvlar va veb – konferentsiyalar-brauzeringizda va mobil ilovalarda.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Hamkorlikdagi hujjatlar, elektron jadvallar va taqdimotlar, Collabora onlayn asosida qurilgan.",
    "Distraction free note taking app." : "Eslatma olish ilovasi.",
    "Recommended apps" : "Tavsiya etilgan ilovalar",
    "Could not fetch list of apps from the App Store." : "App Store dan ilovalar ro'yxatini olib bo'lmadi.",
    "App download or installation failed" : "Ilovani yuklab olish yoki o'rnatish muvaffaqiyatsiz tugadi",
    "Cannot install this app because it is not compatible" : "Ushbu ilovani o'rnatib bo'lmadi, chunki u mos emas",
    "Cannot install this app" : "Ushbu ilovani o'rnatib bo'lmadi",
    "Skip" : "O'tkazib yuborish",
    "Install recommended apps" : "Tavsiya etilgan ilovalarni o'rnating",
    "Online" : "Onlayn",
    "Away" : "Uzoqda",
    "Busy" : "Band",
    "Do not disturb" : "Bezovta qilmang",
    "Mute all notifications" : "Barcha bildirishnomalarni o'chirish",
    "Invisible" : "Ko'rinmas",
    "Appear offline" : "Oflayn ko'rinishda",
    "Avatar of {displayName}" : " {displayName} ning avatari",
    "Settings menu" : "Sozlamalar menyusi",
    "Search contacts" : "Kontaktlarni qidirish",
    "Reset search" : "Qidiruvni tiklash",
    "Could not load your contacts" : "Kontaktlaringizni yuklab bo'lmadi",
    "No contacts found" : "Kontaktlar topilmadi",
    "Show all contacts" : "Show all contacts",
    "Install the Contacts app" : "Kontaktlar ilovasini o'rnating",
    "Search" : "Qidirish",
    "No results for {query}" : " {query}uchun natijalar yo'q",
    "Press Enter to start searching" : "Qidirishni boshlash uchun Enter tugmasini bosing",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Iltimos qidirish uchun belgilar yoki undan ko'p  {minSearchLength} kiriting"],
    "An error occurred while searching for {type}" : " {type}qidirish paytida xatolik yuz berdi",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Yozishni boshlaganingizdan so'ng qidiruv boshlanadi va natijalarga o'q tugmachalari yordamida erishish mumkin",
    "Search for {name} only" : "Faqat {name} qidirish",
    "Forgot password?" : "Parolni unutdingizmi?",
    "Back to login form" : "Kirish formasiga qaytish",
    "Back" : "Orqaga",
    "Login form is disabled." : "Kirish shakli o'chirilgan.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Next bulutli kirish shakli o'chirilgan. Agar mavjud bo'lsa, boshqa kirish opsiyasidan foydalaning yoki administratoringizga murojaat qiling.",
    "More actions" : "Ko'proq harakatlar",
    "Password is too weak" : "Parol juda zaif",
    "Password is weak" : "Parol zaif",
    "Password is average" : "Parol o'rtacha",
    "Password is strong" : "Parol kuchli",
    "Password is very strong" : "Parol juda kuchli",
    "Password is extremely strong" : "Parol juda ham kuchli",
    "Unknown password strength" : "Parol kuchi noma`lum",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : " Sizning ma'lumotlar katalogingiz va fayllaringizga internetdan kirish mumkin, chunki<code>.htaccess</code> fayl ishlamaydi.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : " Serveringizni qanday qilib to'g'ri sozlash haqida ma'lumot olish uchun iltimos{linkStart}dagi {linkEnd}hujjatlarga qarang",
    "Autoconfig file detected" : "Avtokonfig fayli aniqlandi",
    "The setup form below is pre-filled with the values from the config file." : "Quyidagi o'rnatish shakli konfiguratsiya faylidagi qiymatlar bilan oldindan to'ldirilgan.",
    "Security warning" : "Xavfsizlik haqida ogohlantirish",
    "Create administration account" : "Boshqaruv hisobini yarating",
    "Administration account name" : "Administrator akkauntining nomi",
    "Administration account password" : "Administrator akkauntining paroli",
    "Storage & database" : "Saqlash va ma'lumotlar bazasi",
    "Data folder" : "Ma'lumotlar jildi",
    "Database configuration" : "Ma'lumotlar bazasi konfiguratsiyasi",
    "Only {firstAndOnlyDatabase} is available." : "Faqat {firstAndOnlyDatabase} mavjud.",
    "Install and activate additional PHP modules to choose other database types." : "Boshqa ma'lumotlar bazasi turlarini tanlash uchun qo'shimcha PHP modullarini o'rnating va faollashtiring.",
    "For more details check out the documentation." : "Batafsil ma'lumot uchun hujjatlarni tekshiring.",
    "Performance warning" : "Ishlash to'g'risida ogohlantirish",
    "You chose SQLite as database." : "Ma'lumotlar bazasi sifatida SQLite ni tanladingiz.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite faqat minimal va ishlab chiqish misollari uchun ishlatilishi kerak. Ishlab chiqarish uchun biz boshqa ma'lumotlar bazasini tavsiya qilamiz.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Agar siz fayllarni sinxronlashtirish uchun mijozlardan foydalansangiz, SQLite-dan foydalanish juda tavsiya etilmaydi.",
    "Database user" : "Ma'lumotlar bazasi foydalanuvchisi",
    "Database password" : "Ma'lumotlar bazasi paroli",
    "Database name" : "Ma'lumotlar bazasi nomi",
    "Database tablespace" : "Ma'lumotlar bazasi jadval maydoni",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Xost nomi bilan birga port raqamini ko'rsating (masalan, localhost:5432).",
    "Database host" : "Ma'lumotlar bazasi xosti",
    "localhost" : "localhost",
    "Install" : "O'rnatish",
    "Need help?" : "Yordam kerakmi?",
    "See the documentation" : "Hujjatlarga qarang",
    "{name} version {version} and above" : "{name} versiyasi {version} va yuqorida",
    "This browser is not supported" : "Ushbu brauzer qo'llab-quvvatlanmaydi",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Sizning brauzeringiz qo'llab-quvvatlanmaydi. Iltimos, yangiroq yoki qo'llab-quvvatlanadigan versiyaga yangilang.",
    "Continue with this unsupported browser" : "Ushbu qo'llab-quvvatlanmaydigan brauzer bilan davom eting",
    "Supported versions" : "Qo'llab-quvvatlanadigan versiyalar",
    "Choose {file}" : " {file}ta tanlash",
    "Choose" : "Tanlang",
    "Copy to {target}" : " {target}ga nusxalash",
    "Copy" : "Nusxalash",
    "Move to {target}" : " {target}ga o`tish",
    "Move" : "O`tish",
    "OK" : "Yaxshi",
    "read-only" : "faqat o'qish uchun",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fayl xatolilklari"],
    "One file conflict" : "Bitta fayl ziddiyati",
    "New Files" : "Yangi fayllar",
    "Already existing files" : "Allaqachon mavjud fayllar",
    "Which files do you want to keep?" : "Qaysi fayllarni saqlamoqchisiz?",
    "If you select both versions, the copied file will have a number added to its name." : "Ikkala versiyani tanlasangiz, ko'chirilgan fayl nomiga raqam qo'shiladi.",
    "Cancel" : "Bekor qilish",
    "Continue" : "Davom etish",
    "(all selected)" : "(barchasi tanlangan)",
    "({count} selected)" : "({count} tanlangan)",
    "Error loading file exists template" : "Fayl shablonini yuklashda xatolik yuz berdi",
    "seconds ago" : "soniya avval",
    "Connection to server lost" : "Serverga ulanish uzildi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sahifani yuklashda muammo yuz berdi, %n sekundda qayta yuklanmoqda"],
    "Add to a project" : "Loyihaga qo'shish",
    "Show details" : "Tafsilotlarni ko'rsatish",
    "Hide details" : "Tafsilotlarni yashirish",
    "Rename project" : "Loyiha nomini o'zgartirish",
    "Failed to rename the project" : "Loyiha nomini o‘zgartirib bo‘lmadi",
    "Failed to create a project" : "Loyiha yaratib bo‘lmadi",
    "Failed to add the item to the project" : "Ob'ektni loyihaga qo'shib bo'lmadi",
    "Connect items to a project to make them easier to find" : "Elementlarni topishni osonlashtirish uchun ularni loyihaga ulang",
    "Type to search for existing projects" : "Mavjud loyihalarni qidirish uchun kiriting",
    "New in" : "Yangi kiritish",
    "View changelog" : "O'zgarishlar jurnalini ko'rish",
    "Close \"{dialogTitle}\" dialog" : " \"{dialogTitle}\" dialogini yopish",
    "Email length is at max (255)" : "Elektron xabar uzunligi maksimal (255)",
    "Clipboard not available, please copy manually" : "Bufer mavjud emas, qo‘lda nusxa ko‘chiring",
    "Personal" : "Personal",
    "Accounts" : "Akkaunt",
    "Admin" : "Admin",
    "Help" : "Yordam",
    "Access forbidden" : "Kirish taqiqlangan",
    "Back to %s" : "%sga qaytish",
    "Page not found" : "Sahifa topilmadi",
    "The page could not be found on the server or you may not be allowed to view it." : "Sahifani serverda topib bo'lmadi yoki sizga uni ko'rishga ruxsat berilmasligi mumkin.",
    "Too many requests" : "Juda koʻp soʻrovlar",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tarmogʻingizdan juda koʻp soʻrovlar kelib tushdi. Keyinroq qayta urinib ko‘ring yoki xatolik yuz bergan bo‘lsa, administratoringizga murojaat qiling.",
    "Error" : "Xatolik",
    "Internal Server Error" : "Serverdagi ichki xatolik",
    "The server was unable to complete your request." : "Server so‘rovingizni bajara olmadi.",
    "If this happens again, please send the technical details below to the server administrator." : "Agar bu yana takrorlansa, iltimos, quyidagi texnik ma'lumotlarni server administratoriga yuboring.",
    "More details can be found in the server log." : "Batafsil ma'lumotni server jurnalida topishingiz mumkin.",
    "For more details see the documentation ↗." : "Qo'shimcha ma'lumot olish uchun hujjatlarga qarang ↗.",
    "Technical details" : "Texnik tafsilotlar",
    "Remote Address: %s" : "Masofaviy manzil: %s",
    "Request ID: %s" : "So‘rov identifikatori: %s",
    "Type: %s" : "Tip: %s",
    "Code: %s" : "Cod: %s",
    "Message: %s" : "Xabar: %s",
    "File: %s" : "Fayl: %s",
    "Line: %s" : "Chiziq: %s",
    "Trace" : "Izini kuzatish",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Siz Nextcloud-ni qayta o'rnatmoqchi bo'lganga o'xshaysiz. Biroq konfiguratsiya katalogingizda CAN_INSTALL fayli yo‘q. Davom etish uchun konfiguratsiya jildida CAN_INSTALL faylini yarating.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "CAN_INSTALL konfiguratsiya jildidan olib tashlanmadi. Iltimos, ushbu faylni qo'lda olib tashlang.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu ilova toʻgʻri ishlashi uchun JavaScript-ni talab qiladi. iltimos  {linkstart}JavaScript{linkend} ni yoqing va sahifani qayta yuklang.",
    "Skip to main content" : "Asosiy tarkibga o'tish",
    "Skip to navigation of app" : "Ilova navigatsiyasiga oʻtish",
    "Go to %s" : " %sga o`tish",
    "Get your own free account" : "O'zingizning bepul akkauntingizni oling",
    "Connect to your account" : "Akkauntingizni ulang",
    "Please log in before granting %1$s access to your %2$s account." : "Iltimos,  %1$s akkauntingizga kirishdan oldin   %2$s akkauntiga kirishga ruxsat bering.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Agar siz yangi qurilma yoki ilovani oʻrnatmoqchi boʻlmasangiz, kimdir sizni aldab, maʼlumotlaringizga kirish huquqini berishga harakat qilmoqda. Bunday holda davom etmang va o'rniga tizim administratoriga murojaat qiling.",
    "App password" : "Ilova paroli",
    "Grant access" : "Ruxsat berish",
    "Alternative log in using app password" : "Ilova paroli yordamida muqobil tizimga kiring",
    "Account access" : "Hisobga kirish",
    "Currently logged in as %1$s (%2$s)." : "Hozirda  %1$s (%2$s) sifatida tizimga kirgan.",
    "You are about to grant %1$s access to your %2$s account." : " Siz %1$s akkauntiga ruxsat berish arafasidasiz %2$s.",
    "Account connected" : "Akkaunt ulangan",
    "Your client should now be connected!" : "Sizning mijozingiz endi ulangan bo'lishi kerak!",
    "You can close this window." : "Ushbu oynani yopishingiz mumkin.",
    "Previous" : "Oldingi",
    "This share is password-protected" : "Bu almashish parol bilan himoyalangan",
    "The password is wrong or expired. Please try again or request a new one." : "Parol noto'g'ri yoki muddati o'tgan. Iltimos, qayta urinib ko'ring yoki yangisini so'rang.",
    "Please type in your email address to request a temporary password" : "Vaqtinchalik parol so'rash uchun elektron pochta manzilingizni kiriting",
    "Email address" : "E-pochta manzili",
    "Password sent!" : "Parol yuborildi!",
    "You are not authorized to request a password for this share" : "Siz ushbu ulashish uchun parol soʻrash huquqiga ega emassiz",
    "Two-factor authentication" : "Ikki faktorli autentifikatsiya",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hisobingiz uchun kengaytirilgan xavfsizlik yoqilgan. Autentifikatsiya uchun ikkinchi omilni tanlang:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Yoqilgan ikki faktorli autentifikatsiya usullaridan kamida bittasini yuklab bo‘lmadi. Iltimos, adminingizga murojaat qiling.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Ikki faktorli autentifikatsiya joriy qilingan, lekin hisobingizda sozlanmagan. Yordam uchun administratoringizga murojaat qiling.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Ikki faktorli autentifikatsiya joriy qilingan, lekin hisobingizda sozlanmagan. Ikki faktorli autentifikatsiyani sozlashda davom eting.",
    "Set up two-factor authentication" : "Ikki faktorli autentifikatsiyani sozlang",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Ikki faktorli autentifikatsiya joriy qilingan, lekin hisobingizda sozlanmagan. Tizimga kirish uchun zaxira kodlaringizdan birini ishlating yoki yordam uchun administratoringizga murojaat qiling.",
    "Use backup code" : "Zaxira kodidan foydalaning",
    "Cancel login" : "Kirishni bekor qilish",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Akkauntingiz uchun xavfsizlik kuchaytirilgan. Qaysi provayderni sozlashni tanlang:",
    "Error while validating your second factor" : "Ikkinchi omilni tekshirishda xatolik yuz berdi",
    "Access through untrusted domain" : "Ishonchsiz domen orqali kirish",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Iltimos, administratoringizga murojaat qiling. Agar siz administrator bo'lsangiz, config/config.php-dagi \"ishonchli_domenlar\" sozlamasini config.sample.php-dagi misol kabi tahrirlang.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : " %1$sda qanday sozlash haqida qo'shimcha ma'lumotni maqolada topishingiz mumkin %2$s hujjatlarida.",
    "App update required" : "Ilova yangilanishi talab qilinadi",
    "%1$s will be updated to version %2$s" : "%1$s  %2$s versiyasiga yangilanadi",
    "The following apps will be updated:" : "Quyidagi ilovalar yangilanadi:",
    "These incompatible apps will be disabled:" : "Ushbu mos kelmaydigan ilovalar o'chirib qo'yiladi:",
    "The theme %s has been disabled." : "Mavzu %s o'chirilgan.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Davom etishdan oldin maʼlumotlar bazasi, konfiguratsiya papkasi va maʼlumotlar papkasining zaxiralanganligiga ishonch hosil qiling.",
    "Start update" : "Yangilashni boshlang",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Kattaroq o'rnatishlarda vaqt tugashining oldini olish uchun o'rnatish katalogingizdan quyidagi buyruqni ishga tushirishingiz mumkin:",
    "Detailed logs" : "Batafsil jurnallar",
    "Update needed" : "Yangilash kerak",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Iltimos, buyruq qatorini yangilovchidan foydalaning, chunki sizda 50 dan ortiq akkaunt qaydnomalari mavjud.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">ga yordam uchun qarang </a>hujjatlarida.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Agar men veb-UI orqali yangilashni davom ettirsam, so'rovning kutish vaqti tugashi va ma'lumotlar yo'qolishiga olib kelishi xavfi borligini bilaman, lekin menda zaxira nusxasi bor va xatolik yuz berganda misolimni qanday tiklashni bilaman.",
    "Upgrade via web on my own risk" : "veb orqali yangilash, xavfni bo`ynimga olaman",
    "Maintenance mode" : "Texnik rejim",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s misol hozirda sozlanish rejimida, bu biroz vaqt olishi mumkin.",
    "This page will refresh itself when the instance is available again." : "Misol yana mavjud bo'lganda, bu sahifa o'zini yangilaydi.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Agar bu xabar davom etsa yoki kutilmaganda paydo bo'lsa, tizim administratoriga murojaat qiling.",
    "Error occurred while checking server setup" : "Serverni sozlashni tekshirishda xatolik yuz berdi",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Batafsil ma'lumot uchun {linkstart}documentatsiyasini ↗{linkend}qarang.",
    "unknown text" : "noma'lum matn",
    "Hello world!" : "Salom dunyo!",
    "sunny" : "quyoshli",
    "Hello {name}, the weather is {weather}" : "Salom {name}, Ob-havo hozir {weather}",
    "Hello {name}" : "Salom {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Bu sizning qidiruv natijalaringiz<script>ogohlantirish(1)</script></strong>",
    "new" : "yangi",
    "_download %n file_::_download %n files_" : ["fayllarni yuklash %n "],
    "Direct link copied to clipboard" : "Klipbordga nusxa olish",
    "Searching …" : "Qidirilmoqda …",
    "Logging in …" : "Kirilmoqda …",
    "Loading apps …" : "Ilovalarni yuklash …",
    "Installing apps …" : "Ilovalarni o'rnatish …",
    "Loading your contacts …" : "Kontaktlaringiz yuklanmoqda …",
    "Looking for {term} …" : " {term} qidirilmoqda…",
    "Search contacts …" : "Kontaktlarni qidirish …",
    "Loading more results …" : "Ko'proq natijalar yuklanmoqda …",
    "Search {types} …" : " {types}ta qidiruv…",
    "Saving …" : "Saqlanmoqda...",
    "Very weak password" : "Juda zaif parol",
    "Weak password" : "Zaif parol",
    "So-so password" : "Shunday parol",
    "Good password" : "Yaxshi parol",
    "Strong password" : "Kuchli parol",
    "No action available" : "Hech qanday amal mavjud emas",
    "Error fetching contact actions" : "Kontakt amallarini olishda xatolik yuz berdi",
    "Non-existing tag #{tag}" : "Mavjud bo'lmagan teg #{tag}",
    "Restricted" : "Cheklangan",
    "Delete" : "Oʻchirish",
    "Rename" : "Nomini o'zgartirish",
    "Collaborative tags" : "Hamkorlik teglari",
    "No tags found" : "Hech qanday teg topilmadi",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Sizning ma'lumotlar katalog va fayllar, chunki internetdan ehtimol yaxshi bo'ladi .htaccess fayl ishlamaydi.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : " Serveringizni qanday qilib to'g'ri sozlash haqida ma'lumot olish uchun<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">hujjatlarida</a>.",
    "<strong>Create an admin account</strong>" : "<strong>da </strong>administrator akkauntini yarating",
    "New admin account name" : "Administrator akkauntining yangi nomi",
    "New admin password" : "Yangi administrator paroli",
    "Show password" : "Parolni ko'rsatish",
    "Toggle password visibility" : "Parol ko'rinishini o'zgartiring",
    "Configure the database" : "Ma'lumotlar bazasini moslashtiring",
    "Only %s is available." : "Faqat %s uchun mavjud.",
    "Database account" : "Akkauntlar ma`lumotlar bazasi",
    "Installing …" : "Oʻrnatilmoqda…"
},
"nplurals=1; plural=0;");
